summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneycategory.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneycategory.h')
-rw-r--r--kmymoney2/widgets/kmymoneycategory.h46
1 files changed, 24 insertions, 22 deletions
diff --git a/kmymoney2/widgets/kmymoneycategory.h b/kmymoney2/widgets/kmymoneycategory.h
index 474062d..5d90983 100644
--- a/kmymoney2/widgets/kmymoneycategory.h
+++ b/kmymoney2/widgets/kmymoneycategory.h
@@ -21,8 +21,8 @@
// ----------------------------------------------------------------------------
// QT Includes
-class QWidget;
-class QFrame;
+class TQWidget;
+class TQFrame;
// ----------------------------------------------------------------------------
// KDE Includes
@@ -48,7 +48,7 @@ class kMyMoneyAccountSelector;
* If any match is found a list selection box is opened and the user can use
* the up/down, page-up/page-down keys or the mouse to navigate in the list. If
* an account is selected, the selection box is closed. Other key-strokes are
* directed to the parent object to manipulate the text. The visible contents of
* the selection box is updated with every key-stroke.
*
* This object is a replacement of the kMyMoneyCategory object and should be used
@@ -59,26 +59,27 @@ class kMyMoneyAccountSelector;
class KMyMoneyCategory : public KMyMoneyCombo
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Standard constructor for the account selection object.
*
* If parameter @a splitButton is @a true, the widget
* will construct a surrounding QFrame and reparent itself to be a child of this
* QFrame. It also adds a KPushButton with the "Split" icon to the right of the
* input field. In this case it is important not to use the pointer to this widget
* but it's parent when placing the object in a QLayout, QTable or some such. The
* parent widget (the QFrame in this case) can be extracted with the parentWidget()
* method.
*
- * Reparenting is handled by the object transparently for both cases.
+ * Retqparenting is handled by the object transparently for both cases.
*
* Standard usage example (no split button):
*
* @code
* KMyMoneyCategory* category = new KMyMoneyCategory;
* category->reparent(newParent);
- * layout->addWidget(category);
+ * tqlayout->addWidget(category);
* table->setCellWidget(category);
* @endcode
*
@@ -87,11 +88,11 @@ public:
* @code
* KMyMoneyCategory* category = new KMyMoneyCategory(0, 0, true);
* category->reparent(newParent);
- * layout->addWidget(category->parentWidget());
- * table->setCellWidget(category->parentWidget());
+ * tqlayout->addWidget(category->tqparentWidget());
+ * table->setCellWidget(category->tqparentWidget());
* @endcode
*/
- KMyMoneyCategory(QWidget* parent = 0, const char* name = 0, bool splitButton = false);
+ KMyMoneyCategory(TQWidget* tqparent = 0, const char* name = 0, bool splitButton = false);
virtual ~KMyMoneyCategory();
@@ -111,12 +112,12 @@ public:
/**
* Reimplemented for internal reasons. No API change
*/
- virtual void reparent( QWidget *parent, WFlags, const QPoint &, bool showIt = FALSE );
+ virtual void reparent( TQWidget *tqparent, WFlags, const TQPoint &, bool showIt = FALSE );
/**
* Reimplemented for internal reasons. No API change.
*/
- virtual void setPalette(const QPalette& palette);
+ virtual void setPalette(const TQPalette& palette);
/**
* Force the text field to show the text for split transaction.
@@ -131,7 +132,7 @@ public:
/**
* overridden for internal reasons, no API change
*/
- void setCurrentText(const QString& txt = QString()) { KMyMoneyCombo::setCurrentText(txt); }
+ void setCurrentText(const TQString& txt = TQString()) { KMyMoneyCombo::setCurrentText(txt); }
protected:
/**
@@ -139,20 +140,20 @@ protected:
*
* @sa focusIn()
*/
- virtual void focusInEvent(QFocusEvent* ev);
+ virtual void focusInEvent(TQFocusEvent* ev);
/**
* Reimplemented to support protected category text ("split transactions")
*/
- virtual void focusOutEvent(QFocusEvent* ev);
+ virtual void focusOutEvent(TQFocusEvent* ev);
/**
* set the widgets text area based on the item with the given @a id.
*/
- virtual void setCurrentTextById(const QString& id);
+ virtual void setCurrentTextById(const TQString& id);
public slots:
- virtual void slotItemSelected(const QString& id);
+ virtual void slotItemSelected(const TQString& id);
virtual void setEnabled(bool);
virtual void setDisabled(bool);
@@ -177,20 +178,21 @@ private:
class KMyMoneySecurity : public KMyMoneyCategory
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneySecurity(QWidget* parent = 0, const char* name = 0);
+ KMyMoneySecurity(TQWidget* tqparent = 0, const char* name = 0);
virtual ~KMyMoneySecurity();
/**
* overridden for internal reasons, no API change
*/
- void setCurrentText(const QString& txt = QString()) { KMyMoneyCategory::setCurrentText(txt); }
+ void setCurrentText(const TQString& txt = TQString()) { KMyMoneyCategory::setCurrentText(txt); }
protected:
/**
* set the widgets text area based on the item with the given @a id.
*/
- virtual void setCurrentTextById(const QString& id);
+ virtual void setCurrentTextById(const TQString& id);
};
#endif
@@ -48,7 +48,7 @@ class kMyMoneyAccountSelector;
* the up/down, page-up/page-down keys or the mouse to navigate in the list. If
* an account is selected, the selection box is closed. Other key-strokes are
- * directed to the parent object to manipulate the text. The visible contents of
+ * directed to the tqparent object to manipulate the text. The visible contents of
* the selection box is updated with every key-stroke.
*
@@ -59,26 +59,27 @@ class kMyMoneyAccountSelector;
*
* If parameter @a splitButton is @a true, the widget
- * will construct a surrounding QFrame and reparent itself to be a child of this
- * QFrame. It also adds a KPushButton with the "Split" icon to the right of the
+ * will construct a surrounding TQFrame and reparent itself to be a child of this
+ * TQFrame. It also adds a KPushButton with the "Split" icon to the right of the
* input field. In this case it is important not to use the pointer to this widget
@@ -59,26 +59,27 @@ class kMyMoneyAccountSelector;
* input field. In this case it is important not to use the pointer to this widget
- * but it's parent when placing the object in a QLayout, QTable or some such. The
- * parent widget (the QFrame in this case) can be extracted with the parentWidget()
+ * but it's tqparent when placing the object in a TQLayout, TQTable or some such. The
+ * tqparent widget (the TQFrame in this case) can be extracted with the tqparentWidget()
* method.
*